==> kubernetes-model-discovery-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1beta1/EndpointBuilder.java <==
package io.fabric8.kubernetes.api.model.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EndpointBuilder extends EndpointFluentImpl<EndpointBuilder> implements VisitableBuilder<Endpoint,EndpointBuilder>{
  public EndpointBuilder() {
    this(false);
  }
  public EndpointBuilder(Boolean validationEnabled) {
    this(new Endpoint(), validationEnabled);
  }
  public EndpointBuilder(EndpointFluent<?> fluent) {
    this(fluent, false);
  }
  public EndpointBuilder(EndpointFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Endpoint(), validationEnabled);
  }
  public EndpointBuilder(EndpointFluent<?> fluent,Endpoint instance) {
    this(fluent, instance, false);
  }
  public EndpointBuilder(EndpointFluent<?> fluent,Endpoint instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withAddresses(instance.getAddresses());
      fluent.withConditions(instance.getConditions());
      fluent.withHints(instance.getHints());
      fluent.withHostname(instance.getHostname());
      fluent.withNodeName(instance.getNodeName());
      fluent.withTargetRef(instance.getTargetRef());
      fluent.withTopology(instance.getTopology());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EndpointBuilder(Endpoint instance) {
    this(instance,false);
  }
  public EndpointBuilder(Endpoint instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withAddresses(instance.getAddresses());
      this.withConditions(instance.getConditions());
      this.withHints(instance.getHints());
      this.withHostname(instance.getHostname());
      this.withNodeName(instance.getNodeName());
      this.withTargetRef(instance.getTargetRef());
      this.withTopology(instance.getTopology());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EndpointFluent<?> fluent;
  Boolean validationEnabled;
  public Endpoint build() {
    Endpoint buildable = new Endpoint(fluent.getAddresses(),fluent.getConditions(),fluent.getHints(),fluent.getHostname(),fluent.getNodeName(),fluent.getTargetRef(),fluent.getTopology());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-discovery-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/discovery/v1beta1/EndpointBuilder.java <==
package io.fabric8.kubernetes.api.model.discovery.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EndpointBuilder extends EndpointFluent<EndpointBuilder> implements VisitableBuilder<Endpoint,EndpointBuilder>{
  public EndpointBuilder() {
    this(false);
  }
  public EndpointBuilder(Boolean validationEnabled) {
    this(new Endpoint(), validationEnabled);
  }
  public EndpointBuilder(EndpointFluent<?> fluent) {
    this(fluent, false);
  }
  public EndpointBuilder(EndpointFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Endpoint(), validationEnabled);
  }
  public EndpointBuilder(EndpointFluent<?> fluent,Endpoint instance) {
    this(fluent, instance, false);
  }
  public EndpointBuilder(EndpointFluent<?> fluent,Endpoint instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new Endpoint());

    if (instance != null) {
      fluent.withAddresses(instance.getAddresses());
      fluent.withConditions(instance.getConditions());
      fluent.withHints(instance.getHints());
      fluent.withHostname(instance.getHostname());
      fluent.withNodeName(instance.getNodeName());
      fluent.withTargetRef(instance.getTargetRef());
      fluent.withTopology(instance.getTopology());
      fluent.withAddresses(instance.getAddresses());
      fluent.withConditions(instance.getConditions());
      fluent.withHints(instance.getHints());
      fluent.withHostname(instance.getHostname());
      fluent.withNodeName(instance.getNodeName());
      fluent.withTargetRef(instance.getTargetRef());
      fluent.withTopology(instance.getTopology());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EndpointBuilder(Endpoint instance) {
    this(instance,false);
  }
  public EndpointBuilder(Endpoint instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new Endpoint());

    if (instance != null) {
      this.withAddresses(instance.getAddresses());
      this.withConditions(instance.getConditions());
      this.withHints(instance.getHints());
      this.withHostname(instance.getHostname());
      this.withNodeName(instance.getNodeName());
      this.withTargetRef(instance.getTargetRef());
      this.withTopology(instance.getTopology());
      this.withAddresses(instance.getAddresses());
      this.withConditions(instance.getConditions());
      this.withHints(instance.getHints());
      this.withHostname(instance.getHostname());
      this.withNodeName(instance.getNodeName());
      this.withTargetRef(instance.getTargetRef());
      this.withTopology(instance.getTopology());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  EndpointFluent<?> fluent;
  Boolean validationEnabled;
  public Endpoint build() {
    Endpoint buildable = new Endpoint(fluent.getAddresses(),fluent.buildConditions(),fluent.buildHints(),fluent.getHostname(),fluent.getNodeName(),fluent.buildTargetRef(),fluent.getTopology());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
